@@ -2220,20 +2220,31 @@ icaldurationtype ICalFormatImpl::writeICalDuration( const Duration &duration )
   if ( value < 0 ) {
     value = -value;
   }
+  // RFC2445 states that an ical duration value must be
+  // EITHER weeks OR days/time, not both.
   if ( duration.isDaily() ) {
-    d.weeks = value / 7;
-    d.days  = value % 7;
-    d.hours = d.minutes = d.seconds = 0;
+    if ( !( value % 7 ) ) {
+      d.weeks = value / 7;
+      d.days  = 0;
+    } else {
+      d.weeks = 0;
+      d.days  = value;
+      d.hours = d.minutes = d.seconds = 0;
+    }
   } else {
-    d.weeks   = value / gSecondsPerWeek;
-    value    %= gSecondsPerWeek;
-    d.days    = value / gSecondsPerDay;
-    value    %= gSecondsPerDay;
-    d.hours   = value / gSecondsPerHour;
-    value    %= gSecondsPerHour;
-    d.minutes = value / gSecondsPerMinute;
-    value    %= gSecondsPerMinute;
-    d.seconds = value;
+    if ( !( value % gSecondsPerWeek ) ) {
+      d.weeks = value / gSecondsPerWeek;
+      d.days = d.hours = d.minutes = d.seconds = 0;
+    } else {
+      d.weeks   = 0;
+      d.days    = value / gSecondsPerDay;
+      value    %= gSecondsPerDay;
+      d.hours   = value / gSecondsPerHour;
+      value    %= gSecondsPerHour;
+      d.minutes = value / gSecondsPerMinute;
+      value    %= gSecondsPerMinute;
+      d.seconds = value;
+    }
   }
 
   return d;
